@@ -12,10 +12,12 @@ if TYPE_CHECKING:  # pragma: no cover
 class ListingGenerator(PRAWBase, Iterator):
     """Instances of this class generate :class:`.RedditBase` instances.
 
-    .. warning:: This class should not be directly utilized. Instead you will
-       find a number of methods that return instances of the class:
+    .. warning::
 
-       http://praw.readthedocs.io/en/latest/search.html?q=ListingGenerator
+        This class should not be directly utilized. Instead you will find a number of
+        methods that return instances of the class:
+
+        https://praw.readthedocs.io/en/latest/search.html?q=ListingGenerator
 
     """
 
@@ -30,13 +32,12 @@ class ListingGenerator(PRAWBase, Iterator):
 
         :param reddit: An instance of :class:`.Reddit`.
         :param url: A URL returning a reddit listing.
-        :param limit: The number of content entries to fetch. If ``limit`` is
-            None, then fetch as many entries as possible. Most of reddit's
-            listings contain a maximum of 1000 items, and are returned 100 at a
-            time. This class will automatically issue all necessary
-            requests (default: 100).
-        :param params: A dictionary containing additional query string
-            parameters to send with the request.
+        :param limit: The number of content entries to fetch. If ``limit`` is None, then
+            fetch as many entries as possible. Most of reddit's listings contain a
+            maximum of 1000 items, and are returned 100 at a time. This class will
+            automatically issue all necessary requests (default: 100).
+        :param params: A dictionary containing additional query string parameters to
+            send with the request.
 
         """
         super().__init__(reddit, _data=None)
